==> pymol_2.3.0+dfsg.orig.tar.xz: pymol-open-source-2.3.0/layer2/ObjectCGO.h <==

/* 
A* -------------------------------------------------------------------
B* This file contains source code for the PyMOL computer program
C* copyright 1998-2000 by Warren Lyford Delano of DeLano Scientific. 
D* -------------------------------------------------------------------
E* It is unlawful to modify or remove this copyright notice.
F* -------------------------------------------------------------------
G* Please see the accompanying LICENSE file for further information. 
H* -------------------------------------------------------------------
I* Additional authors of this source file include:
-* 
-* 
-*
Z* -------------------------------------------------------------------
*/
#ifndef _H_ObjectCGO
#define _H_ObjectCGO

#include"os_python.h"

#include"PyMOLObject.h"
#include"CGO.h"

typedef struct ObjectCGOState {
  CGO *origCGO;
  CGO *renderCGO;
  bool renderWithShaders, hasTransparency, cgo_lighting, hasOpaque;
} ObjectCGOState;

typedef struct ObjectCGO {
  CObject Obj;
  ObjectCGOState *State;
  int NState;
} ObjectCGO;

ObjectCGO *ObjectCGONew(PyMOLGlobals * G);
ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
                           int state);
ObjectCGO *ObjectCGOFromFloatArray(PyMOLGlobals * G, ObjectCGO * obj, float *array,
                                   int size, int state, int quiet);
ObjectCGO *ObjectCGOFromCGO(PyMOLGlobals * G, ObjectCGO * obj, CGO * cgo, int state);
void ObjectCGORecomputeExtent(ObjectCGO * I);

PyObject *ObjectCGOAsPyList(ObjectCGO * I);
int ObjectCGONewFromPyList(PyMOLGlobals * G, PyObject * list, ObjectCGO ** result,
			       int version);
ObjectCGO *ObjectCGONewVFontTest(PyMOLGlobals * G, const char *text, float *pos);

void ObjectCGOFree(ObjectCGO * I);

#endif

==> pymol_2.4.0+dfsg.orig.tar.xz: pymol-open-source-2.4.0/layer2/ObjectCGO.h <==

/* 
A* -------------------------------------------------------------------
B* This file contains source code for the PyMOL computer program
C* copyright 1998-2000 by Warren Lyford Delano of DeLano Scientific. 
D* -------------------------------------------------------------------
E* It is unlawful to modify or remove this copyright notice.
F* -------------------------------------------------------------------
G* Please see the accompanying LICENSE file for further information. 
H* -------------------------------------------------------------------
I* Additional authors of this source file include:
-* 
-* 
-*
Z* -------------------------------------------------------------------
*/
#ifndef _H_ObjectCGO
#define _H_ObjectCGO

#include"os_python.h"

#include"PyMOLObject.h"
#include"CGO.h"

typedef struct ObjectCGOState {
  CGO *origCGO;
  CGO *renderCGO;
  bool renderWithShaders, hasTransparency, cgo_lighting, hasOpaque;
} ObjectCGOState;

struct ObjectCGO : public CObject {
  ObjectCGOState *State = nullptr;
  int NState = 0;
  ObjectCGO(PyMOLGlobals* G);
  ~ObjectCGO();

  // virtual methods
  void update() override;
  void render(RenderInfo* info) override;
  void invalidate(int rep, int level, int state) override;
  int getNFrame() const override;
};

ObjectCGO *ObjectCGODefine(PyMOLGlobals * G, ObjectCGO * obj, PyObject * pycgo,
                           int state);
ObjectCGO *ObjectCGOFromFloatArray(PyMOLGlobals * G, ObjectCGO * obj, float *array,
                                   int size, int state, int quiet);
ObjectCGO *ObjectCGOFromCGO(PyMOLGlobals * G, ObjectCGO * obj, CGO * cgo, int state);
void ObjectCGORecomputeExtent(ObjectCGO * I);

PyObject *ObjectCGOAsPyList(ObjectCGO * I);
int ObjectCGONewFromPyList(PyMOLGlobals * G, PyObject * list, ObjectCGO ** result,
			       int version);
ObjectCGO *ObjectCGONewVFontTest(PyMOLGlobals * G, const char *text, float *pos);

#endif
